@@ -57,8 +57,10 @@ class Premailer(BasePremailer):
         for idx, path_part in enumerate(reversed(path_parts)):
             if path_part == static_url_parts[-1]:
                 # We found where STATIC_URL begins.
-                rel_path = '/'.join(path_parts[idx:])
+                rel_path = '/'.join(path_parts[len(path_parts) - idx:])
                 break
+        LOGGER.debug("looking for '%s' in order into directories %s",
+            url, get_assets_dirs())
         for base_path in get_assets_dirs():
             stylefile = safe_join(base_path, rel_path)
             if os.path.exists(stylefile):
